
---------------------------------------------------
-- [v1.01.00] Make sure we have nUI tables
---------------------------------------------------
if not nUI_InfoPanels then nUI_InfoPanels = {}; end

----------------------------------------------------------------
-- [v1.01.00] Localized Functions and Tables to speed things up
----------------------------------------------------------------
local _L = nUI_InfoPanel_GuildInfo_L;

---------------------------------------------------
-- [v1.01.00] Allocation of the Window ID (unique)
---------------------------------------------------
nUI_INFOMODE_GUILDINFO  = 25;
nUI_INFOPANEL_GUILDINFO = "nUI_InfoPanel_GuildInfo";

---------------------------------------------------
-- [v1.01.00] Some Constants
---------------------------------------------------

---------------------------------------------------
-- [v1.01.00] Set the Default values for the Infopanel
---------------------------------------------------
nUI_InfoPanels[nUI_INFOPANEL_GUILDINFO ] =
{	
	enabled   = true,
	desc      = _L["Info Panel Text"],             -- player friendly name/description of the panel
	label     = _L["Info Panel Label"],	       -- label to use on the panel selection button face
	rotation  = nUI_INFOMODE_GUILDINFO,            -- index or position this panel appears on/in when clicking the selector button
	full_size = true;                              -- this plugin requires the entire info panel port without the button bag
	
	options  =
	{
		enabled  = true,
	},
};

---------------------------------------------------
-- [v1.01.00] Set Plugin Values
---------------------------------------------------
local plugin    = CreateFrame( "Frame", nUI_INFOPANEL_GUILDINFO, nUI_Dashboard.Anchor );
plugin.active   = true;

---------------------------------------------------
-- [v1.01.00] Validate Addon is loaded
---------------------------------------------------
local function onGuildInfoEvent()
	if event == "VARIABLES_LOADED" then		
		GuildInfo_CreateFrame();
		if ( not GuildInfo.Frame ) then
			plugin.active = false;
		end
	end	
end
plugin:SetScript( "OnEvent", onGuildInfoEvent );
plugin:RegisterEvent( "VARIABLES_LOADED" );

---------------------------------------------------
-- [v1.01.00] Disable GuildInfo Frame
---------------------------------------------------
disableGuildInfo = function()
end

---------------------------------------------------
-- [v1.01.00] Enable the GuildInfo Frame
---------------------------------------------------
enableGuildInfo = function()
	local GuildInfo = GuildInfo.Frame;
	plugin.GuildInfo = GuildInfo;
	
	-- Set the GuildInfo Frame to fit into the info panel
	nUI_Movers:lockFrame( GuildInfo, false, nil );
	GuildInfo:SetParent( plugin.container );
	GuildInfo:SetPoint( "TOPLEFT", plugin.container, "TOPLEFT", 10, -10 );
	GuildInfo:SetPoint( "BOTTOMRIGHT", plugin.container, "BOTTOMRIGHT", -10, 10 );
	GuildInfo:SetFrameStrata( plugin.container:GetFrameStrata() );
	GuildInfo:SetFrameLevel( plugin.container:GetFrameLevel()+1 );
	GuildInfo:SetBackdropBorderColor( 0, 0, 0, 0 );
	GuildInfo:SetBackdropColor( 0, 0, 0, 0 );	
	nUI_Movers:lockFrame( GuildInfo, true, nil );

end


---------------------------------------------------
-- [v1.01.00] Resize the GuildInfo Frame
---------------------------------------------------
resizeGuildInfo = function(height,width)
	local GuildInfo   = plugin.GuildInfo;
	nUI_Movers:lockFrame( GuildInfo, false, nil );
	GuildInfo:SetWidth( width ); 
	GuildInfo:SetHeight( height ); 
	nUI_Movers:lockFrame( GuildInfo, true, nil );
end

---------------------------------------------------
-- [v1.01.00] The Infopanel has been selected so make sure the addon is activated as well
---------------------------------------------------
selectGuildInfo = function()
	GuildRoster();
end

---------------------------------------------------
-- [v1.01.00] initPanel routine
---------------------------------------------------
plugin.initPanel = function( container, options )
	plugin.container = container;
	plugin.options   = options;
	if options and options.enabled then
		plugin.setEnabled( true );
	end
end

---------------------------------------------------
-- [v1.01.00] sizeChanged routine
---------------------------------------------------
plugin.sizeChanged = function( scale, height, width )
	local options  = plugin.options;
	plugin.scale = scale;
	resizeGuildInfo(height,width);
end	

---------------------------------------------------
-- [v1.01.00] Validate Enable Status
---------------------------------------------------
plugin.setEnabled = function( enabled )
	if plugin.enabled ~= enabled then
		plugin.enabled = enabled;
		if not enabled then
			disableGuildInfo();
		else
			enableGuildInfo();
		end				
	end			
end

---------------------------------------------------
-- [v1.01.00] setSelected routine
---------------------------------------------------
plugin.setSelected = function( selected )
	if selected ~= plugin.selected then
		plugin.selected = selected;
		if selected then
			selectGuildInfo();
		else
		end
	end
end
